@@ -1,9 +1,12 @@
 """:mod:`wand.color` --- Colors
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+.. versionadded:: 0.1.2
+
 """
 import ctypes
-from .api import library, MagickPixelPacket
+
+from .api import MagickPixelPacket, library
 from .resource import Resource
 
 __all__ = 'Color',
