@@ -10,14 +10,15 @@ error happened)::
         print 'height =', i.height
 
 """
-import types
-import numbers
 import collections
 import ctypes
+import numbers
 import platform
-from .api import library, libmagick, libc, MagickPixelPacket
-from .resource import Resource, DestroyedResourceError
+import types
+
+from .api import MagickPixelPacket, libc, libmagick, library
 from .color import Color
+from .resource import DestroyedResourceError, Resource
 
 
 __all__ = 'FILTER_TYPES', 'Image', 'Iterator', 'ClosedImageError'
@@ -38,22 +39,250 @@ __all__ = 'FILTER_TYPES', 'Image', 'Iterator', 'ClosedImageError'
 #: - ``'cubic'``
 #: - ``'catrom'``
 #: - ``'mitchell'``
-#: - ``'lanczos'``
-#: - ``'bessel'``
+#: - ``'jinc'``
 #: - ``'sinc'``
+#: - ``'sincfast'``
+#: - ``'kaiser'``
+#: - ``'welsh'``
+#: - ``'parzen'``
+#: - ``'bohman'``
+#: - ``'bartlett'``
+#: - ``'lagrange'``
+#: - ``'lanczos'``
+#: - ``'lanczossharp'``
+#: - ``'lanczos2'``
+#: - ``'lanczos2sharp'``
+#: - ``'robidoux'``
+#: - ``'robidouxsharp'``
+#: - ``'cosine'``
+#: - ``'spline'``
+#: - ``'sentinel'``
 #:
 #: .. seealso::
 #:
 #:    `ImageMagick Resize Filters`__
-#:       Demonstrates the results of resampling three images using the various
-#:       resize filters and blur settings available in ImageMagick,
-#:       and the file size of the resulting thumbnail images.
+#:       Demonstrates the results of resampling images using the various
+#:       resize filters and blur settings available in ImageMagick.
 #:
-#:    __ http://www.dylanbeattie.net/magick/filters/result.html
+#:    __ http://www.imagemagick.org/Usage/resize/
 FILTER_TYPES = ('undefined', 'point', 'box', 'triangle', 'hermite', 'hanning',
                 'hamming', 'blackman', 'gaussian', 'quadratic', 'cubic',
-                'catrom', 'mitchell', 'lanczos', 'bessel', 'sinc')
+                'catrom', 'mitchell', 'jinc', 'sinc', 'sincfast', 'kaiser',
+                'welsh', 'parzen', 'bohman', 'bartlett', 'lagrange', 'lanczos',
+                'lanczossharp', 'lanczos2', 'lanczos2sharp', 'robidoux',
+                'robidouxsharp', 'cosine', 'spline', 'sentinel')
 
+#: (:class:`tuple`) The list of composition operators
+#:
+#: - ``'undefined'``
+#: - ``'no'``
+#: - ``'add'``
+#: - ``'atop'``
+#: - ``'blend'``
+#: - ``'bumpmap'``
+#: - ``'change_mask'``
+#: - ``'clear'``
+#: - ``'color_burn'``
+#: - ``'color_dodge'``
+#: - ``'colorize'``
+#: - ``'copy_black'``
+#: - ``'copy_blue'``
+#: - ``'copy'``
+#: - ``'copy_cyan'``
+#: - ``'copy_green'``
+#: - ``'copy_magenta'``
+#: - ``'copy_opacity'``
+#: - ``'copy_red'``
+#: - ``'copy_yellow'``
+#: - ``'darken'``
+#: - ``'dst_atop'``
+#: - ``'dst'``
+#: - ``'dst_in'``
+#: - ``'dst_out'``
+#: - ``'dst_over'``
+#: - ``'difference'``
+#: - ``'displace'``
+#: - ``'dissolve'``
+#: - ``'exclusion'``
+#: - ``'hard_light'``
+#: - ``'hue'``
+#: - ``'in'``
+#: - ``'lighten'``
+#: - ``'linear_light'``
+#: - ``'luminize'``
+#: - ``'minus'``
+#: - ``'modulate'``
+#: - ``'multiply'``
+#: - ``'out'``
+#: - ``'over'``
+#: - ``'overlay'``
+#: - ``'plus'``
+#: - ``'replace'``
+#: - ``'saturate'``
+#: - ``'screen'``
+#: - ``'soft_light'``
+#: - ``'src_atop'``
+#: - ``'src'``
+#: - ``'src_in'``
+#: - ``'src_out'``
+#: - ``'src_over'``
+#: - ``'subtract'``
+#: - ``'threshold'``
+#: - ``'xor'``
+#: - ``'divide'``
+#:
+#: .. seealso::
+#:
+#:    `ImageMagick Composition Operators`__
+#:       Demonstrates the results of applying the various composition
+#:       composition operators.
+#:
+#:    __ http://www.rubblewebs.co.uk/imagemagick/operators/compose.php
+COMPOSITE_OPS = ('undefined', 'no', 'add', 'atop', 'blend', 'bumpmap',
+                 'change_mask', 'clear', 'color_burn', 'color_dodge',
+                 'colorize', 'copy_black', 'copy_blue', 'copy', 'copy_cyan',
+                 'copy_green', 'copy_magenta', 'copy_opacity', 'copy_red',
+                 'copy_yellow', 'darken', 'dst_atop', 'dst', 'dst_in',
+                 'dst_out', 'dst_over', 'difference', 'displace',
+                 'dissolve', 'exclusion', 'hard_light', 'hue', 'in',
+                 'lighten', 'linear_light', 'luminize', 'minus', 'modulate',
+                 'multiply', 'out', 'over', 'overlay', 'plus', 'replace',
+                 'saturate', 'screen', 'soft_light', 'src_atop', 'src',
+                 'src_in', 'src_out', 'src_over', 'subtract', 'threshold',
+                 'xor', 'divide',)
+
+#: (:class:`dict`) The dictionary of channel types.
+#:
+#: - ``'undefined'``
+#: - ``'red'``
+#: - ``'gray'``
+#: - ``'cyan'``
+#: - ``'green'``
+#: - ``'magenta'``
+#: - ``'blue'``
+#: - ``'yellow'``
+#: - ``'black'``
+#: - ``'alpha'``
+#: - ``'opacity'``
+#: - ``'index'``
+#: - ``'mask'``
+#: - ``'meta'``
+#:
+#: .. seealso::
+#:
+#:    `ImageMagick Color Channels`__
+#:       Lists the various channel types with descriptions of each
+#:
+#:    __ http://www.imagemagick.org/Magick++/Enumerations.html#ChannelType
+CHANNELS = dict(undefined=0, red=1, gray=1, cyan=1, green=2, magenta=2,
+                blue=4, yellow=4, black=8, alpha=16, opacity=16, index=32,
+                mask=64, meta=128)
+
+#: (:class:`tuple`) The list of evaluation operators
+#:
+#: - ``'undefined'``
+#: - ``'add'``
+#: - ``'and'``
+#: - ``'divide'``
+#: - ``'leftshift'``
+#: - ``'max'``
+#: - ``'min'``
+#: - ``'multiply'``
+#: - ``'or'``
+#: - ``'rightshift'``
+#: - ``'set'``
+#: - ``'subtract'``
+#: - ``'xor'``
+#: - ``'pow'``
+#: - ``'log'``
+#: - ``'threshold'``
+#: - ``'thresholdblack'``
+#: - ``'thresholdwhite'``
+#: - ``'gaussiannoise'``
+#: - ``'impulsenoise'``
+#: - ``'laplaciannoise'``
+#: - ``'multiplicativenoise'``
+#: - ``'poissonnoise'``
+#: - ``'uniformnoise'``
+#: - ``'cosine'``
+#: - ``'sine'``
+#: - ``'addmodulus'``
+#: - ``'mean'``
+#: - ``'abs'``
+#: - ``'exponential'``
+#: - ``'median'``
+#: - ``'sum'``
+#:
+#: .. seealso::
+#:
+#:    `ImageMagick Image Evaluation Operators`__
+#:       Describes the MagickEvaluateImageChannel method and lists the
+#:       various evaluations operators
+#:
+#:    __ http://www.magickwand.org/MagickEvaluateImage.html
+EVALUATE_OPS = ('undefined', 'add', 'and', 'divide', 'leftshift', 'max',
+                'min', 'multiply', 'or', 'rightshift', 'set', 'subtract',
+                'xor', 'pow', 'log', 'threshold', 'thresholdblack',
+                'thresholdwhite', 'gaussiannoise', 'impulsenoise',
+                'laplaciannoise', 'multiplicativenoise', 'poissonnoise',
+                'uniformnoise', 'cosine', 'sine', 'addmodulus', 'mean',
+                'abs', 'exponential', 'median', 'sum',)
+
+#: (:class:`tuple`) The list of alpha chanell types
+#:
+#: - ``'undefinedalphachannel'``
+#: - ``'activatealphachannel'``
+#: - ``'backgroundalphachannel'``
+#: - ``'copyalphachannel'``
+#: - ``'deactivatealphachannel'``
+#: - ``'extractalphachannel'``
+#: - ``'opaquealphachannel'``
+#: - ``'resetalphachannel'``
+#: - ``'setalphachannel'``
+#: - ``'shapealphachannel'``
+#: - ``'transparentalphachannel'``
+#: - ``'flattenalphachannel'``
+#: - ``'removealphachannel'``
+#:
+#: .. seealso::
+#:    `ImageMagick Image Channel`__
+#:       Describes the SetImageAlphaChannel method which can be used
+#:       to modify alpha channel. Also describes AlphaChannelType
+#:    __ http://www.imagemagick.org/api/channel.php#SetImageAlphaChannel
+ALPHA_CHANNEL_TYPES = ('undefinedalphachannel', 'activatealphachannel',
+                       'backgroundalphachannel', 'copyalphachannel',
+                       'deactivatealphachannel', 'extractalphachannel',
+                       'opaquealphachannel', 'resetalphachannel',
+                       'setalphachannel', 'shapealphachannel',
+                       'transparentalphachannel', 'flattenalphachannel',
+                       'removealphachannel',)
+
+#: (:class:`tuple`) The list of image types
+#:
+#: - ``'undefined'``
+#: - ``'bilevel'``
+#: - ``'grayscale'``
+#: - ``'grayscalematte'``
+#: - ``'palette'``
+#: - ``'palettematte'``
+#: - ``'truecolor'``
+#: - ``'truecolormatte'``
+#: - ``'colorseparation'``
+#: - ``'colorseparationmatte'``
+#: - ``'optimize'``
+#: - ``'palettebilevelmatte'``
+#:
+#: .. seealso::
+#:
+#:    `ImageMagick Image Types`__
+#:       Describes the MagickSetImageType method which can be used
+#:       to set the type of an image
+#:
+#:    __ http://www.imagemagick.org/api/magick-image.php#MagickSetImageType
+IMAGE_TYPES = ('undefined', 'bilevel', 'grayscale', 'grayscalematte',
+               'palette', 'palettematte', 'truecolor', 'truecolormatte',
+               'colorseparation', 'colorseparationmatte', 'optimize',
+               'palettebilevelmatte',)
 
 class Image(Resource):
     """An image object.
@@ -66,6 +295,19 @@ class Image(Resource):
     :type file: file object
     :param filename: opens an image of the ``filename`` string
     :type filename: :class:`basestring`
+    :param format: forces filename to  buffer.``format`` to help
+                   imagemagick detect the file format. Used only in
+                   ``blob`` or ``file`` cases
+    :type format: :class:`basestring`
+
+    .. versionadded:: 0.1.5
+       The ``file`` parameter.
+
+    .. versionadded:: 0.1.1
+       The ``blob`` parameter.
+
+    .. versionadded:: 0.2.1
+       The ``format`` parameter.
 
     .. describe:: [left:right, top:bottom]
 
@@ -89,6 +331,8 @@ class Image(Resource):
        :returns: the cropped image
        :rtype: :class:`Image`
 
+       .. versionadded:: 0.1.2
+
     """
 
     c_is_resource = library.IsMagickWand
@@ -98,7 +342,8 @@ class Image(Resource):
 
     __slots__ = '_wand',
 
-    def __init__(self, image=None, blob=None, file=None, filename=None):
+    def __init__(self, image=None, blob=None, file=None, filename=None,
+                 format=None):
         args = image, blob, file, filename
         if all(a is None for a in args):
             raise TypeError('missing arguments')
@@ -107,16 +352,24 @@ class Image(Resource):
                  for b in args[:i] + args[i + 1:]):
             raise TypeError('parameters are exclusive each other; use only '
                             'one at once')
+        elif not (format is None or isinstance(format, basestring)):
+            raise TypeError('format must be a string, not ' + repr(format))
         with self.allocate():
             if image is not None:
                 if not isinstance(image, Image):
                     raise TypeError('image must be a wand.image.Image '
                                     'instance, not ' + repr(image))
+                elif format:
+                    raise TypeError('format option cannot be used with image '
+                                    'nor filename')
                 self.wand = library.CloneMagickWand(image.wand)
             else:
                 self.wand = library.NewMagickWand()
                 read = False
                 if file is not None:
+                    if format:
+                        library.MagickSetFilename(self.wand,
+                                                  'buffer.' + format)
                     if (isinstance(file, types.FileType) and
                         hasattr(libc, 'fdopen')):
                         fd = libc.fdopen(file.fileno(), file.mode)
@@ -130,6 +383,9 @@ class Image(Resource):
                         blob = file.read()
                         file = None
                 if blob is not None:
+                    if format:
+                        library.MagickSetFilename(self.wand,
+                                                  'buffer.' + format)
                     if not isinstance(blob, collections.Iterable):
                         raise TypeError('blob must be iterable, not ' +
                                         repr(blob))
@@ -140,6 +396,11 @@ class Image(Resource):
                     library.MagickReadImageBlob(self.wand, blob, len(blob))
                     read = True
                 elif filename is not None:
+                    if format:
+                        raise TypeError(
+                            'format option cannot be used with image '
+                            'nor filename'
+                        )
                     library.MagickReadImage(self.wand, filename)
                     read = True
                 if not read:
@@ -191,6 +452,8 @@ class Image(Resource):
         :returns: the cloned new image
         :rtype: :class:`Image`
 
+        .. versionadded:: 0.1.1
+
         """
         return type(self)(image=self)
 
@@ -290,6 +553,21 @@ class Image(Resource):
         """(:class:`tuple`) The pair of (:attr:`width`, :attr:`height`)."""
         return self.width, self.height
 
+    @property
+    def depth(self):
+        """(:class:`numbers.Integral`) The depth of this image.
+
+        .. versionadded:: 0.2.1
+
+        """
+        return library.MagickGetImageDepth(self.wand)
+
+    @depth.setter
+    def depth(self, depth):
+        r = library.MagickSetImageDepth(self.wand, depth)
+        if not r:
+            raise self.raise_exception()
+
     @property
     def format(self):
         """(:class:`basestring`) The image format.
@@ -310,6 +588,8 @@ class Image(Resource):
 
            __ http://www.imagemagick.org/script/formats.php
 
+        .. versionadded:: 0.1.6
+
         """
         fmt = library.MagickGetImageFormat(self.wand)
         if fmt:
@@ -325,11 +605,38 @@ class Image(Resource):
         if not r:
             raise ValueError(repr(fmt) + ' is unsupported format')
 
+    @property
+    def compression_quality(self):
+        """(:class:`numbers.Integral`) Compression quality of this image.
+
+        .. versionadded:: 0.2.0
+
+        """
+        return library.MagickGetImageCompressionQuality(self.wand)
+
+    @compression_quality.setter
+    def compression_quality(self, quality):
+        """Set compression quality for the image.
+
+        :param quality: new compression quality setting
+        :type quality: :class:`numbers.Integral`
+
+        """
+        if not isinstance(quality, numbers.Integral):
+            raise TypeError('compression quality must be a natural '
+                            'number, not ' + repr(quality))
+        r = library.MagickSetImageCompressionQuality(self.wand, quality)
+        if not r:
+            raise ValueError('Unable to set compression quality to ' +
+                             repr(quality))
+
     @property
     def mimetype(self):
         """(:class:`basestring`) The MIME type of the image
         e.g. ``'image/jpeg'``, ``'image/png'``.
 
+        .. versionadded:: 0.1.7
+
         """
         rp = libmagick.MagickToMime(self.format)
         if not rp:
@@ -348,14 +655,47 @@ class Image(Resource):
         """(:class:`str`) The SHA-256 message digest for the image pixel
         stream.
 
+        .. versionadded:: 0.1.9
+
         """
         return library.MagickGetImageSignature(self.wand)
 
+    @property
+    def alpha_channel(self):
+        """(:class:`bool`) Get state of image alpha channel.
+        It can also be used to enable/disable alpha channel.
+
+        .. versionadded:: 0.2.1
+
+        .. todo::
+
+           Support other states than ``''activatealphachannel'``
+           or ``'deactivatealphachannel'``.
+
+        """
+        return library.MagickGetImageAlphaChannel(self.wand)
+
+    @alpha_channel.setter
+    def alpha_channel(self, alpha):
+        if alpha == True:
+            act = ALPHA_CHANNEL_TYPES.index('activatealphachannel')
+        elif alpha == False:
+            act = ALPHA_CHANNEL_TYPES.index('deactivatealphachannel')
+        else:
+            raise TypeError('alpha_channel must be bool, not ' +
+                            repr(alpha))
+        r = library.MagickSetImageAlphaChannel(self.wand, act)
+        if r:
+            return r
+        self.raise_exception()
+
     @property
     def background_color(self):
         """(:class:`wand.color.Color`) The image background color.
         It can also be set to change the background color.
 
+        .. versionadded:: 0.1.9
+
         """
         pixel = library.NewPixelWand()
         result = library.MagickGetImageBackgroundColor(self.wand, pixel)
@@ -366,6 +706,18 @@ class Image(Resource):
             return Color(raw=buffer)
         self.raise_exception()
 
+    @property
+    def quantum_range(self):
+        """(:class:`int`) The maxumim value of a color channel that is
+        supported by the imagemgick library.
+
+        .. versionadded:: 0.2.0
+
+        """
+        result = ctypes.c_size_t()
+        library.MagickGetQuantumRange(ctypes.byref(result))
+        return result.value
+
     @background_color.setter
     def background_color(self, color):
         if not isinstance(color, Color):
@@ -390,13 +742,15 @@ class Image(Resource):
         :rtype: :class:`Image`
         :raises: :exc:`ValueError` when the given ``format`` is unsupported
 
+        .. versionadded:: 0.1.6
+
         """
         cloned = self.clone()
         cloned.format = format
         return cloned
 
     def crop(self, left=0, top=0, right=None, bottom=None,
-             width=None, height=None):
+             width=None, height=None, reset_coords=True):
         """Crops the image in-place.
 
         .. sourcecode:: text
@@ -441,12 +795,26 @@ class Image(Resource):
                        this parameter and ``bottom`` parameter are exclusive
                        each other
         :type height: :class:`numbers.Integral`
+        :param reset_coords:
+           optional flag. If set, after the rotation, the coordinate frame
+           will be relocated to the upper-left corner of the new image.
+           By default is `True`.
+        :type reset_coords: :class:`bool`
+        :raises exceptions.ValueError:
+           when one or more arguments are invalid
 
         .. note::
 
            If you want to crop the image but not in-place, use slicing
            operator.
 
+        .. versionchanged:: 0.1.8
+           Made to raise :exc:`~exceptions.ValueError` instead of
+           :exc:`~exceptions.IndexError` for invalid ``width``/``height``
+           arguments.
+
+        .. versionadded:: 0.1.7
+
         """
         if not (right is None or width is None):
             raise TypeError('parameters right and width are exclusive each '
@@ -478,8 +846,19 @@ class Image(Resource):
             return
         library.MagickCropImage(self.wand, width, height, left, top)
         self.raise_exception()
+        if reset_coords:
+            self.reset_coords()
 
-    def resize(self, width=None, height=None, filter='triangle', blur=1):
+    def reset_coords(self):
+        """Reset the coordinate frame of the image so to the upper-left corner
+        is (0, 0) again (crop and rotate operations change it).
+
+        .. versionadded:: 0.2.0
+
+        """
+        library.MagickResetImagePage(self.wand, None)
+
+    def resize(self, width=None, height=None, filter='undefined', blur=1):
         """Resizes the image.
 
         :param width: the width in the scaled image. default is the original
@@ -489,12 +868,23 @@ class Image(Resource):
                        height
         :type height: :class:`numbers.Integral`
         :param filter: a filter type to use for resizing. choose one in
-                       :const:`FILTER_TYPES`. default is ``'triangle'``
+                       :const:`FILTER_TYPES`. default is ``'undefined'``
+                       which means IM will try to guess best one to use
         :type filter: :class:`basestring`, :class:`numbers.Integral`
         :param blur: the blur factor where > 1 is blurry, < 1 is sharp.
                      default is 1
         :type blur: :class:`numbers.Real`
 
+        .. versionchanged:: 0.2.1
+           The default value of ``filter`` has changed from ``'triangle'``
+           to ``'undefined'`` instead.
+
+        .. versionchanged:: 0.1.8
+           The ``blur`` parameter changed to take :class:`numbers.Real`
+           instead of :class:`numbers.Rational`.
+
+        .. versionadded:: 0.1.1
+
         """
         if width is None:
             width = self.width
@@ -529,7 +919,7 @@ class Image(Resource):
         blur = ctypes.c_double(float(blur))
         library.MagickResizeImage(self.wand, width, height, filter, blur)
 
-    def rotate(self, degree, background=None):
+    def rotate(self, degree, background=None, reset_coords=True):
         """Rotates the image. It takes a ``background`` color for ``degree``
         that isn't a multiple of 90.
 
@@ -538,6 +928,15 @@ class Image(Resource):
         :param background: an optional background color.
                            default is transparent
         :type background: :class:`wand.color.Color`
+        :param reset_coords: optional flag. If set, after the rotation, the
+            coordinate frame will be relocated to the upper-left corner of
+            the new image. By default is `True`.
+        :type reset_coords: :class:`bool`
+
+        .. versionadded:: 0.2.0
+           The ``reset_coords`` parameter.
+
+        .. versionadded:: 0.1.8
 
         """
         if background is None:
@@ -554,6 +953,81 @@ class Image(Resource):
                                                degree)
         if not result:
             self.raise_exception()
+        if reset_coords:
+            self.reset_coords()
+
+    def transparentize(self, transparency):
+        """Makes the image transparent by subtracting some percentage of
+        the black color channel.  The ``transparency`` parameter specifies the
+        percentage.
+
+        :param transparency: the percentage fade that should be performed on the
+                             image, from 0.0 to 1.0
+        :type transparency: :class:`numbers.Real`
+
+        .. versionadded:: 0.2.0
+
+        """
+        if transparency:
+            t = ctypes.c_double(float(self.quantum_range * float(transparency)))
+            if t.value > self.quantum_range or t.value < 0:
+                raise ValueError('transparency must be a numbers.Real value ' +
+                                 'between 0.0 and 1.0')
+            # Set the wand to image zero, incase there are multiple images in it
+            library.MagickSetIteratorIndex(self.wand, 0)
+            # Change the pixel representation of the image
+            # to RGB with an alpha channel
+            library.MagickSetImageType(self.wand,
+                                       IMAGE_TYPES.index('truecolormatte'))
+            # Perform the black channel subtraction
+            library.MagickEvaluateImageChannel(self.wand,
+                                               CHANNELS.get('black', 8),
+                                               EVALUATE_OPS.index('subtract'),
+                                               t)
+            self.raise_exception()
+
+    def composite(self, image, left, top):
+        """Places the supplied ``image`` over the current image, with the top
+        left corner of ``image`` at coordinates ``left``, ``top`` of the
+        current image.  The dimensions of the current image are not changed.
+
+        :param image: the image placed over the current image
+        :type image: :class:`wand.image.Image`
+        :param left: the x-coordinate where `image` will be placed
+        :type left: :class:`numbers.Integral`
+        :param top: the y-coordinate where `image` will be placed
+        :type top: :class:`numbers.Integral`
+
+        .. versionadded:: 0.2.0
+
+        """
+        library.MagickCompositeImage(self.wand, image.wand,
+                                     COMPOSITE_OPS.index('over'), left, top)
+        self.raise_exception()
+
+    def watermark(self, image, transparency=0.0, left=0, top=0):
+        """Transparentized the supplied ``image`` and places it over the
+        current image, with the top left corner of ``image`` at coordinates
+        ``left``, ``top`` of the current image.  The dimensions of the
+        current image are not changed.
+
+        :param image: the image placed over the current image
+        :type image: :class:`wand.image.Image`
+        :param transparency: the percentage fade that should be performed on
+                             the image, from 0.0 to 1.0
+        :type transparency: :class:`numbers.Real`
+        :param left: the x-coordinate where `image` will be placed
+        :type left: :class:`numbers.Integral`
+        :param top: the y-coordinate where `image` will be placed
+        :type top: :class:`numbers.Integral`
+
+        .. versionadded:: 0.2.0
+
+        """
+        with image.clone() as watermark_image:
+            watermark_image.transparentize(transparency)
+            self.composite(watermark_image, left, top)
+        self.raise_exception()
 
     def save(self, file=None, filename=None):
         """Saves the image into the ``file`` or ``filename``. It takes
@@ -564,6 +1038,11 @@ class Image(Resource):
         :param filename: a filename string to write to
         :type filename: :class:`basename`
 
+        .. versionadded:: 0.1.5
+           The ``file`` parameter.
+
+        .. versionadded:: 0.1.1
+
         """
         if file is None and filename is None:
             raise TypeError('expected an argument')
@@ -599,6 +1078,15 @@ class Image(Resource):
         :rtype: :class:`str`
         :raises: :exc:`ValueError` when ``format`` is invalid
 
+        .. versionchanged:: 0.1.6
+           Removed a side effect that changes the image :attr:`format`
+           silently.
+
+        .. versionadded:: 0.1.5
+           The ``format`` parameter became optional.
+
+        .. versionadded:: 0.1.1
+
         """
         if format is not None:
             with self.convert(format) as converted:
@@ -612,6 +1100,25 @@ class Image(Resource):
             return blob
         self.raise_exception()
 
+    def strip(self):
+        """Strips an image of all profiles and comments.
+
+        .. versionadded:: 0.2.0
+
+        """
+        result = library.MagickStripImage(self.wand)
+        if not result:
+            self.raise_exception()
+
+    def trim(self):
+        """Remove solid border from image. Uses top left pixel as a guide.
+
+        .. versionadded:: 0.2.1
+
+        """
+        result = library.MagickTrimImage(self.wand)
+        if not result:
+            self.raise_exception()
 
 class Iterator(Resource, collections.Iterator):
     """Row iterator for :class:`Image`. It shouldn't be instantiated
@@ -633,6 +1140,8 @@ class Iterator(Resource, collections.Iterator):
     :param image: the image to get an iterator
     :type image: :class:`Image`
 
+    .. versionadded:: 0.1.3
+
     """
 
     c_is_resource = library.IsPixelIterator
@@ -699,7 +1208,9 @@ class Iterator(Resource, collections.Iterator):
         return Color(raw=packet_buffer)
 
     def clone(self):
-        """Clones the same iterator."""
+        """Clones the same iterator.
+
+        """
         return type(self)(iterator=self)
 
 
